@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::iata;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2018-10-29 - v1.004
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.052.
+
+=item *
+
 2017-11-13 - v1.003
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.051.
@@ -180,7 +186,7 @@ DND DNE DNG DNH DNI DNK DNL DNM DNN DNO DNP DNR DNS DNT DNU DNV DNX DNZ
 DOA DOB DOC DOD DOE DOF DOG DOH DOI DOK DOL DOM DON DOO DOP DOR DOS DOU
 DOV DOX DPA DPC DPE DPG DPH DPL DPO DPS DPU DRA DRB DRC DRD DRE DRF DRG
 DRH DRI DRJ DRM DRN DRO DRR DRS DRT DRU DRW DRY DSA DSC DSD DSE DSG DSI
-DSK DSL DSM DSN DSV DTA DTD DTE DTH DTL DTM DTN DTO DTR DTS DTW DTX
+DSK DSL DSM DSN DSS DSV DTA DTD DTE DTH DTL DTM DTN DTO DTR DTS DTW DTX
 DUA DUB DUC DUD DUE DUF DUG DUI DUJ DUK DUM DUN DUO DUR DUS DUT DVA DVL
 DVN DVO DVP DVR DVT DWA DWB DWC DWD DWF DWH DWN DWS DXA DXB DXD DXR DYA
 DYG DYL DYM DYR DYS DYU DYW DZA DZN DZO DZU EAA EAB EAE EAM EAN EAR
@@ -529,7 +535,7 @@ TBK TBL TBM TBN TBO TBP TBQ TBR TBS TBT TBU TBV TBW TBX TBY TBZ TCA TCB
 TCC TCD TCE TCF TCG TCH TCJ TCK TCL TCM TCN TCO TCP TCQ TCR TCS TCT
 TCU TCV TCW TCX TCY TDA TDB TDD TDG TDJ TDK TDL TDN TDO TDR TDT TDV TDW
 TDZ TEA TEB TEC TED TEE TEF TEG TEH TEI TEK TEL TEM TEN TEO TEP TEQ TER
-TES TET TEU TEX TEY TEZ TFA TFF TFI TFL TFM TFN TFR TFS TFT TFX TFY TGA
+TES TET TEU TEV TEX TEY TEZ TFA TFF TFI TFL TFM TFN TFR TFS TFT TFX TFY TGA
 TGB TGD TGE TGF TGG TGH TGI TGJ TGL TGM TGN TGO TGQ TGR TGS TGT TGU TGV
 TGX TGZ THA THB THC THE THF THG THH THI THK THL THM THN THO THP THR THS
 THT THU THV THY THZ TIA TIB TIC TID TIE TIF TIG TIH TII TIJ TIK TIL TIM
