@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2018-10-29 - v1.006
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.052.
+
+=item *
+
 2017-11-13 - v1.005
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.051.
@@ -233,9 +239,9 @@ FYRK FYRU FYSM FYWE FYWH FZAA FZAG FZAM FZAN FZBA FZBO FZCA FZCS FZEA FZFK
 FZGN FZIA FZMB FZNA FZNC FZOA FZQA FZQM FZRA FZRF FZRQ FZSA FZUA FZUH
 FZUK FZVA FZVI FZVS FZWA GABG GABS GAGO GAHB GAKA GAKL GAKO GAKT GAKY
 GAMB GAMK GANK GANR GASG GASK GASN GATB GATS GBYD GCFV GCGM GCHI GCLA
-GCLP GCRR GCTS GCXO GECE GEML GFHA GFLL GGBF GGOV GLMR GLRB GMAA GMAD
-GMAT GMFF GMFI GMFK GMFM GMFN GMFO GMFZ GMMC GMME GMMF GMMI GMMN GMMS
-GMMW GMMX GMMY GMMZ GMTA GMTN GMTT GOGG GOGK GOGS GOOD GOOG GOOK GOOY
+GCLP GCRR GCTS GCXO GECE GEML GFHA GFLL GGBF GGOV GLMR GLRB GMAA GMAD GMAG
+GMAT GMFF GMFI GMFK GMFM GMFN GMFO GMFZ GMMA GMMC GMME GMMF GMMH GMMI GMML GMMN GMMS
+GMMW GMMX GMMY GMMZ GMTA GMTN GMTT GOBD GOGG GOGK GOGS GOOD GOOG GOOK GOOY
 GOSM GOSP GOSS GOTB GOTK GOTT GQNA GQNB GQND GQNF GQNI GQNJ GQNK GQNN
 GQNR GQPA GQPP GQPT GSVO GUCY GUFH GUID GUKU GULB GUMA GUNZ GUOK GUSI
 GUXD GVAC GVAN GVBA GVFM GVMA GVMT GVSF GVSN GVSV HAAB HAAG HAAM HAAW
@@ -270,7 +276,7 @@ KBLH KBLI KBLM KBLU KBLV KBLW KBLX KBMC KBMG KBMI KBML KBMQ KBMT KBMX
 KBNA KBNF KBNG KBNH KBNL KBNO KBNW KBNY KBOF KBOI KBOK KBOS KBOW KBOX
 KBPA KBPG KBPI KBPK KBPT KBQK KBQV KBRD KBRG KBRL KBRO KBRY KBSF KBSI
 KBSM KBSQ KBSW KBSZ KBTF KBTI KBTL KBTM KBTN KBTP KBTR KBTV KBTY KBUB
-KBUF KBUM KBUO KBUR KBUY KBVD KBVE KBVI KBVO KBVU KBVY KBWC KBWD KBWG
+KBUF KBUM KBUO KBUR KBUY KBVD KBVI KBVO KBVU KBVY KBWC KBWD KBWG
 KBWI KBWL KBWM KBWS KBXA KBXC KBXK KBXS KBYA KBYG KBYH KBYI KBYS KBYW
 KBZN KBZS KBZT KCAD KCAE KCAG KCAK KCAO KCAR KCAV KCBA KCBE KCBF KCBG
 KCBK KCBM KCBZ KCCA KCCB KCCD KCCG KCCR KCCX KCCY KCDC KCDH KCDK KCDL
@@ -362,7 +368,7 @@ KMRH KMRK KMRN KMRX KMRY KMSC KMSD KMSL KMSN KMSO KMSP KMSS KMSV KMSX
 KMSY KMTC KMTH KMTJ KMTM KMTN KMTO KMTP KMTV KMTW KMTX KMUE KMUI KMUL
 KMUO KMUT KMUU KMUV KMUX KMVC KMVE KMVL KMVM KMVN KMVW KMVY KMWA KMWC
 KMWH KMWL KMWM KMWN KMWO KMWS KMXA KMXC KMXE KMXF KMXG KMXO KMXY KMYF KMYH
-KMYK KMYL KMYR KMYU KMYV KMZJ KMZZ KNAB KNAK KNAX KNBC KNBE KNBG KNBJ KNBP
+KMYK KMYL KMYR KMYU KMYV KMZJ KMZZ KNAB KNAX KNBC KNBE KNBG KNBJ KNBP
 KNBQ KNBU KNCA KNCN KNCO KNDP KNDV KNDZ KNEA KNED KNEL KNEN KNES KNEW KNEX
 KNFB KNFE KNFG KNFJ KNFL KNFW KNGC KNGP KNGU KNGW KNGZ KNHK KNHX KNHZ
 KNIB KNID KNIE KNIN KNIP KNIR KNIS KNJK KNJM KNJW KNKI KNKT KNKV KNKX
@@ -403,7 +409,7 @@ KSCC KSCF KSCH KSCJ KSCK KSCM KSCR KSDA KSDB KSDF KSDL KSDM KSDP KSDX
 KSDY KSEA KSEE KSEG KSEM KSEP KSER KSES KSFB KSFF KSFM KSFO KSFR KSFZ
 KSGF KSGH KSGR KSGT KSGU KSGW KSHD KSHG KSHH KSHL KSHN KSHP KSHR KSHV
 KSHX KSIK KSIV KSIY KSJC KSJN KSJT KSKA KSKC KSKF KSKJ KSKK KSKW KSKY
-KSLB KSLC KSLE KSLG KSLI KSLJ KSLK KSLN KSLO KSLQ KSLR KSLT KSLW KSMD
+KSLB KSLC KSLE KSLG KSLI KSLJ KSLK KSLN KSLO KSLQ KSLR KSLT KSMD
 KSME KSMF KSMK KSMN KSMO KSMP KSMU KSMX KSNA KSNK KSNL KSNS KSNY KSOL
 KSOP KSOW KSOY KSPA KSPF KSPG KSPI KSPQ KSPS KSPW KSPX KSPZ KSQA KSQI
 KSQL KSQV KSRC KSRF KSRQ KSRR KSRU KSRV KSRW KSSC KSSF KSSI KSSU KSSW
@@ -437,14 +443,14 @@ LBSZ LBTG LBVD LBWB LBWN LCCC LCEN LCLK LCNC LCPH LCRA LDDD LDDU LDLO LDOC
 LDOR LDOS LDPL LDRI LDSB LDSH LDSP LDVA LDZA LDZD LEAB LEAL LEAM LEAS
 LEBA LEBB LEBG LEBL LEBZ LECH LECO LECU LECV LEDA LEFA LEGE LEGR LEGT
 LEHI LEIB LEJR LELC LELL LELN LELO LEMD LEMG LEMH LEMO LEMU LEPA LEPP
-LEPR LERI LERS LERT LESA LESO LEST LESU LETO LEVC LEVD LEVT LEVX LEXJ
+LEPR LERI LERS LERT LESA LESO LEST LESU LETL LETO LEVC LEVD LEVT LEVX LEXJ
 LEZA LEZG LEZL LFAB LFAC LFAD LFAF LFAG LFAK LFAT LFAY LFBA LFBB LFBC
 LFBD LFBE LFBF LFBG LFBH LFBI LFBK LFBL LFBM LFBN LFBO LFBP LFBS LFBT
 LFBU LFBV LFBW LFBX LFBY LFBZ LFCA LFCC LFCE LFCG LFCH LFCI LFCK LFCL
 LFCR LFCS LFCY LFDB LFDH LFDI LFDM LFDN LFDO LFDS LFDT LFER LFFS LFGJ
 LFHP LFHY LFHZ LFIG LFJL LFJM LFKB LFKC LFKF LFKG LFKJ LFKO LFKS LFKT
 LFLA LFLB LFLC LFLD LFLI LFLJ LFLL LFLM LFLN LFLQ LFLS LFLV LFLW LFLX
-LFLY LFMA LFMC LFMD LFME LFMH LFMI LFMK LFML LFMN LFMO LFMP LFMT LFMU
+LFLY LFMA LFMC LFMD LFME LFMH LFMI LFMK LFML LFMN LFMO LFMP LFMR LFMT LFMU
 LFMV LFMX LFMY LFNB LFOB LFOC LFOE LFOF LFOH LFOI LFOJ LFOK LFOP LFOR
 LFOS LFOT LFOW LFPB LFPC LFPG LFPI LFPM LFPN LFPO LFPV LFPW LFQB LFQG
 LFQH LFQI LFQQ LFQV LFRB LFRC LFRD LFRE LFRG LFRH LFRI LFRJ LFRK LFRL
@@ -524,7 +530,7 @@ OPKH OPKL OPKT OPLA OPLH OPLL OPMF OPMI OPMJ OPMP OPMT OPNH OPNK OPOR
 OPPC OPPG OPPI OPPS OPQT OPRK OPRN OPRS OPRT OPSB OPSD OPSK OPSN OPSR
 OPSS OPST OPSU OPSW OPTA OPTH OPTT OPTU OPWN OPZB ORAA ORAT ORBB ORBI
 ORBM ORBS ORER ORKK ORMM ORMS ORQW ORSU ORTF ORTK ORTL OSAP OSDI OSDZ
-OSKL OSLK OSPR OTBH OTDB OYAA OYAB OYAT OYHD OYMB OYMC OYMK OYRN OYSH
+OSKL OSLK OSPR OTBH OTDB OTHH OYAA OYAB OYAT OYHD OYMB OYMC OYMK OYRN OYSH
 OYSN OYSQ OYSY OYTZ OYZM PAAK PAAL PAAP PAAQ PABA PABE PABI PABN PABR
 PABT PABV PACD PACL PACP PACR PACS PACV PACY PACZ PADE PADK PADL PADQ
 PADT PADU PAEC PAED PAEH PAEI PAEL PAEM PAEN PAFA PAFB PAFE PAFM PAFR
@@ -593,7 +599,7 @@ TBPB TBPO TDCF TDPD TDPR TFFF TFFG TFFJ TFFR TGPY TIST TISX TJBQ TJCP
 TJFA TJFF TJIG TJMZ TJNR TJPS TJSJ TJVQ TKPK TKPN TLPC TLPL TNCA TNCB
 TNCC TNCE TNCM TNCS TQPF TRPM TTCP TTPP TTPT TUPJ TVSB TVSC TVSM TVSU
 TVSV TXKF UAAA UAAH UAAT UACC UACP UADD UAFF UAFL UAFM UAFO UAFP UAII UAKK
-UAOO UARR UATA UATE UATG UATT UBBB UBTT UDSG UDYZ UEEE UELL UGKK UGKO
+UAOO UARR UATA UATE UATG UATT UBBB UBTT UDSG UDYZ UEEE UELL UESK UGKK UGKO
 UGKS UGMM UGSB UGSS UGTB UHBP UHHH UHHO UHMA UHMD UHMM UHMP UHPP UHSS
 UHWW UIAA UIII UIIO UIKB UIKK UINN UIUH UIUU UKBB UKBD UKCC UKCM UKCW
 UKDD UKDE UKDR UKFB UKFF UKFK UKFW UKFY UKHE UKHH UKHK UKHP UKHS UKII
@@ -624,11 +630,11 @@ VYPT VYPU VYRN VYRR VYSW VYSY VYTD VYYE VYYY WAAA WAAB WAAS WAAU WABB
 WABI WABN WABO WABT WADD WAJI WAJJ WAJW WAKK WAKT WAMA WAME WAMG WAMH
 WAMI WAML WAMM WAMP WAMT WAMW WAOK WAPA WAPH WAPI WAPN WAPP WAPR WASF WASK
 WASR WASS WBGB WBGG WBGR WBGS WBKK WBKL WBKS WBKT WBKW WBSB WIAA WIAG
-WIAM WIAR WIAS WIBB WIDD WIDN WIIA WIIB WIIH WIII WIIJ WIIK WIIL WIIS
+WIAM WIAR WIAS WIBB WIDD WIDN WIIA WIIB WIII WIIJ WIIK WIIL WIIS
 WIIT WIKD WIKK WIKS WIMB WIMG WIMM WIMS WIOI WIOK WION WIOO WIOS WIPA
 WIPH WIPL WIPP WIPR WIPT WITC WITM WITT WMBA WMKA WMKC WMKD WMKI WMKJ
 WMKK WMKL WMKM WMKN WMKP WMSA WPDL WPEC WPOC WRBB WRBI WRBM WRBP
-WRKC WRKK WRKL WRKM WRKR WRKS WRLB WRLG WRLK WRLL WRLR WRLS WRRA WRRB
+WRKC WRKK WRKL WRKM WRKR WRKS WRLB WRLG WRLK WRLL WRLR WRLS WRRB
 WRRS WRRW WRSJ WRSP WRSQ WRSS WSAP WSAT WSSL WSSS YAYE YBAF YBAM YBAS
 YBBN YBCG YBCS YBCV YBGL YBLR YBMA YBMC YBMK YBOK YBPN YBRK YBRM YBTL
 YBWP YCMT YDTC YDYL YMAV YMAY YMDV YMEK YMEN YMES YMHB YMLT YMLV YMMB
@@ -637,5 +643,5 @@ YPDN YPEA YPED YPFT YPGN YPGV YPJT YPKA YPKG YPKU YPLC YPLM YPPD YPPF
 YPPH YPTN YPWR YPXM YSBK YSCB YSCH YSCM YSCN YSDU YSNF YSNW YSRI YSSY
 YSTW YSWG YSWM YTEF YWLM YWYY ZBAA ZBHH ZBTJ ZBYN ZGCS ZGGG ZGHK ZGKL
 ZGNN ZGOW ZGSZ ZGZJ ZHCC ZHHH ZKKC ZKPY ZLAN ZLIC ZLJQ ZLSN ZLXN ZLXY
-ZLYA ZMUB ZPPP ZSAM ZSCN ZSFZ ZSGZ ZSHC ZSNJ ZSOF ZSPD ZSQD ZSSS ZSTN
+ZLYA ZMUB ZPPP ZSAM ZSCN ZSFZ ZSGZ ZSHC ZSJN ZSNJ ZSOF ZSPD ZSQD ZSSS
 ZUCK ZUGY ZULS ZUUU ZUXC ZWHM ZWSH ZWTN ZWWW ZWYN ZYCC ZYQQ ZYTL ZYTX ZYYJ
