@@ -2,10 +2,12 @@ package Acme::MetaSyntactic::octothorpe;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 1;
 
+=encoding iso-8859-1
+
 =head1 NAME
 
 Acme::MetaSyntactic::octothorpe - The octothorpe theme
@@ -21,10 +23,10 @@ L<http://www.worldwidewords.org/weirdwords/ww-oct1.htm> for other stories.
 If you know another name for C<#> that is not included in this list,
 please send it to me, with a reference to back up your claim. Thanks.
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
 Philippe "BooK" Bruhat, inspired by David Landgren's presentation of
-L<Acme::DonMartin>.
+L<Acme::DonMartin>, Sbastien Aperghis-Tramoni.
 
 =head1 CHANGES
 
@@ -32,6 +34,13 @@ L<Acme::DonMartin>.
 
 =item *
 
+2013-02-18 - v1.001
+
+Sbastien Aperghis-Tramoni submitted a new name (I<diamond>),
+published in Acme-MetaSyntactic-Themes version 1.030.
+
+=item *
+
 2012-05-07 - v1.000
 
 Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
@@ -55,6 +64,7 @@ __DATA__
 comment_sign
 crosshatch
 crunch
+diamond
 fence
 flash
 gate
